@@ -2,6 +2,9 @@
 #define RCOOKIEJAR_H
 
 #include <QNetworkCookieJar>
+#include <QVariantMap>
+
+#include <QByteArray>
 
 class RCookieJar : public QNetworkCookieJar
 {
@@ -11,10 +14,13 @@ public:
 
     virtual bool setCookiesFromUrl ( const QList<QNetworkCookie> & cookieList, const QUrl & url );
 
-
+    QByteArray store();
+    void restore(const QByteArray& stored);
 signals:
 
 public slots:
+    QVariantMap cookies();
+
 
 };
 
