@@ -15,10 +15,12 @@
 #include <QFileInfo>
 #include <QNetworkCookieJar>
 #include <QNetworkCookie>
+#include <QCoreApplication>
 
 #include "rcookiejar.h"
 
 #include "platutil.h"
+#include <QSettings>
 
 //#define RSTEST
 
@@ -26,11 +28,23 @@ RedditSession::RedditSession(QObject *parent) :
     QObject(parent)
 {
     m_net = new QNetworkAccessManager(this);
-    m_net->setCookieJar(new RCookieJar(this));
-    m_eng = new QScriptEngine;
 
+
+    m_eng = new QScriptEngine;
+    QCoreApplication::setOrganizationName("VilleSoft");
+    QCoreApplication::setOrganizationDomain("unknown.domain");
+    QCoreApplication::setApplicationName("QmlReddit");
+
+    RCookieJar* cj = new RCookieJar(this);
+    QSettings s;
+    QVariant v = s.value("Auth/Cookies");
+    if (v.isValid())
+        cj->restore(v.toByteArray());
+
+    m_net->setCookieJar(cj);
 }
 
+
 void RedditSession::start(const QString& cat)
 {
 
@@ -83,7 +97,7 @@ void RedditSession::linksFetched()
         QString url = v.property("url").toString();
         QString title = v.property("title").toString();        
         QString tnail = v.property("thumbnail").toString();
-        QString name = v.property("name").toString();
+        QString name = v.property("name").toString();        
         expandHtmlEntities(title);
 
         int score = v.property("score").toInt32();
@@ -224,9 +238,15 @@ QStringList RedditSession::getCategories()
 {
     //return QStringList() << "programming" << "pics";
 
+    QStringList cats;
+
+    cats << m_myreddits;
+
     QString cf = PlatUtil::configFile();
     //qDebug() << "Config " << cf;
     QFileInfo fi(cf);
+
+
     if (!fi.exists()) {
         QFile f(cf);
         f.open(QFile::WriteOnly);
@@ -244,7 +264,6 @@ QStringList RedditSession::getCategories()
     bool r = f.open(QFile::ReadOnly);
     Q_ASSERT(r);
 
-    QStringList cats;
     QTextStream ts(&f);
     for (;;) {
         if (ts.atEnd())
@@ -264,6 +283,8 @@ QStringList RedditSession::getCategories()
 
     }
 
+    cats.removeDuplicates();
+
     return cats;
 
 }
@@ -304,27 +325,18 @@ void RedditSession::loginFinished()
     if (!reply)
         return;
 
+    // the session id gets saved to cookies
+    // modhash to be digged up later
 
-    qDebug() << "loginfinish " << reply->readAll();
+    QByteArray resp = reply->readAll();
+    QString s = resp;
+    emit loginResponse(s);
+    qDebug() << "loginfinish " << s;
 
-
-    QNetworkRequest getMine(QUrl("http://www.reddit.com/reddits/mine/.json"));
-    QNetworkReply* reply2 = m_net->get(getMine);
-
-    connect(reply2, SIGNAL(finished()), this, SLOT(getMyRedditsFinished()));
-
-
-/*
-Vote:
-www.reddit.com/api/vote
-cookie required
-POSTDATA: id=t1_abc1010&dir=1&r=android&uh=f0f0f0f0f0f0f0f0f0f0f0
-id is “thing id” of thing you’re voting for.
-dir = 1, 0, or -1. “direction” of vote.
-r = subreddit name
-uh = user modhash
-
-*/
+    if (RCookieJar* cj = qobject_cast<RCookieJar*>(m_net->cookieJar())) {
+        QSettings setts;
+        setts.setValue("Auth/Cookies", cj->store());
+    }
 
 }
 
@@ -335,9 +347,10 @@ void RedditSession::getMyRedditsFinished()
         return;
 
     QByteArray ba = reply->readAll();
-    qDebug() << "data " << ba;
+    //qDebug() << "data " << ba;
     QScriptValue sv = parseJson(ba);
-    QString modhash = sv.property("data").property("modhash").toString();
+    m_modhash = sv.property("data").property("modhash").toString();
+    qDebug() << "modhash " << m_modhash;
     QScriptValue items = sv.property("data").property("children");
     QScriptValueIterator it(items);
     m_myreddits.clear();
@@ -348,5 +361,65 @@ void RedditSession::getMyRedditsFinished()
         m_myreddits.append(dname);
         qDebug() << "my " << dname;
     }
+    emit categoriesUpdated();
+
 }
 
+QVariantMap RedditSession::cookies()
+{
+    RCookieJar* jar = qobject_cast<RCookieJar*> (m_net->cookieJar());
+    if (!jar)
+        return QVariantMap();
+
+    return jar->cookies();
+
+}
+
+void RedditSession::setModhash(const QString &modhash)
+{
+    m_modhash = modhash;
+
+}
+
+void RedditSession::vote(const QString &thing, int votedir)
+{
+    /*
+    Vote:
+    www.reddit.com/api/vote
+    cookie required
+    POSTDATA: id=t1_abc1010&dir=1&r=android&uh=f0f0f0f0f0f0f0f0f0f0f0
+    id is “thing id” of thing you’re voting for.
+    dir = 1, 0, or -1. “direction” of vote.
+    r = subreddit name
+    uh = user modhash
+
+    */
+
+    QString url = "http://www.reddit.com/api/vote";
+
+    QNetworkRequest req(url);
+
+    QUrl params;
+    params.addQueryItem("id", thing);
+    params.addQueryItem("dir", QString::number(votedir));
+    params.addQueryItem("uh", m_modhash);
+
+    QByteArray postcont = params.toEncoded();
+    postcont.remove(0,1);
+    qDebug() << "posting " << postcont;
+    QNetworkReply* reply = m_net->post(req, postcont);
+    Q_UNUSED(reply);
+}
+
+void RedditSession::getMyReddits()
+{
+
+    QNetworkRequest getMine(QUrl("http://www.reddit.com/reddits/mine/.json"));
+    QNetworkReply* reply2 = m_net->get(getMine);
+
+    connect(reply2, SIGNAL(finished()), this, SLOT(getMyRedditsFinished()));
+
+
+}
+
+
